Anjara Fanompoana

Andriamatoa sy ramatoa isany

<% def modifdate(daty): if "/" in daty: daty=daty.replace("/","-") daty="-".join((daty[6:10],daty[3:5],daty[0:2])) return daty if "-" in daty: daty=daty.replace("-","/") daty="/".join((daty[8:10],daty[5:7],daty[0:4])) return daty %> <% ll=0 sz=len(dd) %> %for ddl in dd: <%ll+=1%>
%if ll==3 or ll==4:
%endif

${modifdate(ddl)}

% for rows in data: % if rows[0]==ddl:
% for value in rows: % if value != ddl: ${value} % endif % endfor
% endif % endfor

%endfor